import Vue from 'vue'
import VueRouter from 'vue-router'

import DefaultLayout from '@/layouts/DefaultLayout/index.vue'

Vue.use(VueRouter)

export const routes = [
  {
    path: '/',
    component: DefaultLayout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import(/* webpackChunkName: "dashboard" */ '@/views/dashboard/index.vue'),
        name: 'Dashboard',
        meta: {
          title: '首页',
          icon: 'dashboard',
          affix: true
        }
      }
    ]
  },
  {
    path: '/template',
    component: DefaultLayout,
    redirect: '/list',
    meta: {
      title: '模板管理'
    },
    children: [
      {
        path: 'list',
        name: 'templateList',
        meta: {
          title: '模板列表'
        },
        component: () => import('@/views/Template/List/index.vue')
      }
    ]
  },
  {
    path: '/form',
    component: DefaultLayout,
    redirect: '/design',
    meta: {
      title: '表单管理'
    },
    children: [
      {
        path: 'design',
        name: 'formDesign',
        meta: {
          title: '表单设计'
        },
        component: () => import('@/views/Form/FormDesign/Home.vue')
      },
      {
        path: 'model',
        name: 'formModel',
        meta: {
          title: '表单模型'
        },
        component: () => import('@/views/Form/FormModel/index.vue')
      },
      {
        path: '/parser',
        name: 'parser',
        meta: {
          title: '表单解析'
        },
        component: () => import(/* webpackChunkName: "parser-example" */'@/components/parser/example/Index.vue')
      }
    ]
  },
  {
    path: '/list',
    component: DefaultLayout,
    redirect: '/design',
    meta: {
      title: '列表管理'
    },
    children: [
      {
        path: 'design',
        name: 'listDesign',
        meta: {
          title: '列表设计'
        },
        component: () => import('@/views/List/ListDesign/index.vue')
      },
      {
        path: 'model',
        name: 'listModel',
        meta: {
          title: '列表模型'
        },
        component: () => import('@/views/List/ListModel/index.vue')
      }
    ]
  },
  {
    path: '/tinymce',
    name: 'tinymce',
    component: DefaultLayout,
    redirect: 'tinymce',
    children: [
      {
        path: '/index',
        name: 'tinymceText',
        meta: {
          title: '富文本'
        },
        component: () => import(/* webpackChunkName: "tinymce-example" */'@/components/tinymce/example/Index.vue')
      }
    ]
  }
]

const router = new VueRouter({
  routes,
  mode: 'history'
})

export default router
